CREATE DATABASE tfc;

DROP TABLE usuario;
CREATE TABLE usuario
(
id_usuario INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
nombre VARCHAR(30),
apellido VARCHAR(30),
email VARCHAR(30) NOT NULL UNIQUE,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_usuario PRIMARY KEY(id_usuario)
); 
DESC usuario;

DROP TABLE credenciales;
CREATE TABLE credenciales
(
id_credenciales INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cuenta VARCHAR(30) NOT NULL UNIQUE,
clave VARCHAR(16) NOT NULL,
id_usuario INT(10) NOT NULL,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_credenciales PRIMARY KEY(id_credenciales),
CONSTRAINT fk_usuario FOREIGN KEY(id_usuario) REFERENCES usuario(id_usuario)
); 
DESC credenciales;

DROP TABLE recurso;
CREATE TABLE recurso
(
id_recurso INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
descripcion VARCHAR(30) NOT NULL,
url VARCHAR(100) NOT NULL UNIQUE,
id_usuario INT(10) NOT NULL,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_recurso PRIMARY KEY(id_recurso),
CONSTRAINT fk_usuario FOREIGN KEY(id_usuario) REFERENCES usuario(id_usuario)
); 
DESC recurso;

DROP TABLE relacion;
CREATE TABLE relacion
(
id_relacion INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
rol VARCHAR(200) NOT NULL,
invitacion TINYINT(1) DEFAULT 0,
id_usuario_1 INT(10) NOT NULL,
id_usuario_2 INT(10) NOT NULL,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_relacion PRIMARY KEY(id_relacion),
CONSTRAINT fk_usuario_1 FOREIGN KEY(id_usuario_1) REFERENCES usuario(id_usuario),
CONSTRAINT fk_usuario_2 FOREIGN KEY(id_usuario_2) REFERENCES usuario(id_usuario)
);
DESC relacion;

DROP TABLE comunidad;
CREATE TABLE comunidad
(
id_comunidad INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
nombre VARCHAR(60) NOT NULL UNIQUE,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_comunidad PRIMARY KEY(id_comunidad)
); 
DESC comunidad;

DROP TABLE perfil;
CREATE TABLE perfil
(
id_perfil INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
descripcion VARCHAR(30) NOT NULL,
id_usuario INT(10) NOT NULL,
id_comunidad INT(10) NOT NULL,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_perfil PRIMARY KEY(id_perfil),
CONSTRAINT fk_usuario FOREIGN KEY(id_usuario) REFERENCES usuario(id_usuario),
CONSTRAINT fk_comunidad FOREIGN KEY(id_comunidad) REFERENCES comunidad(id_comunidad)
); 
DESC perfil;

DROP TABLE mensaje;
CREATE TABLE mensaje
(
id_mensaje INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
texto VARCHAR(200) NOT NULL,
id_mensaje_original INT(10) NOT NULL,
id_usuario INT(10) NOT NULL,
id_comunidad INT(10) NOT NULL,
estado TINYINT(1) DEFAULT 0,
CONSTRAINT pk_mensaje PRIMARY KEY(id_mensaje),
CONSTRAINT fk_mensaje FOREIGN KEY(id_mensaje_original) REFERENCES mensaje(id_mensaje),
CONSTRAINT fk_usuario FOREIGN KEY(id_usuario) REFERENCES usuario(id_usuario),
CONSTRAINT fk_comunidad FOREIGN KEY(id_comunidad) REFERENCES comunidad(id_comunidad)
); 
DESC mensaje;

