package tfc.jvilarodr.logic;

import java.util.ArrayList;
import java.util.Map;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.xml.ws.WebServiceRef;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.comunidades.ServicioComunidad.Comunidad;
import tfc.jvilarodr.ws.comunidades.ServicioComunidad.Comunidades;
import tfc.jvilarodr.ws.comunidades.ServicioComunidad.ServicioComunidad;
import tfc.jvilarodr.ws.comunidades.ServicioMensaje.Mensaje;
import tfc.jvilarodr.ws.comunidades.ServicioMensaje.ServicioMensaje;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.Usuarios;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean
@SessionScoped
public class AccesoComunidad {
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/usuarios/ServicioUsuario.wsdl")
    private Usuarios wsUsuario;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/comunidades/ServicioComunidad.wsdl")
    private Comunidades wsComunidad;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/comunidades/ServicioPerfil.wsdl")
    private tfc.jvilarodr.ws.comunidades.ServicioPerfil.Comunidades wsPerfil;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/comunidades/ServicioMensaje.wsdl")
    private tfc.jvilarodr.ws.comunidades.ServicioMensaje.Comunidades wsMensaje;

    public static AccesoComunidad getCurrentInstance() {
        AccesoComunidad result = null;
        FacesContext context = FacesContext.getCurrentInstance();
        Map<String, Object> appMap = FacesContext.getCurrentInstance().
                getExternalContext().getApplicationMap();
        result = (AccesoComunidad) appMap.get("accesoComunidad");
        
        Map<String, Object> sessionMap = context.getExternalContext().getSessionMap();
        if (null == (result = (AccesoComunidad) sessionMap.get("accesoComunidad"))){
            result = context.getApplication().evaluateExpressionGet(context, "#{accesoComunidad}",
                    AccesoComunidad.class);
        }        
        assert(null != result);

        return result;
    }   
    
    public void registrar(final Comunidad comunidad) throws AccesoException {
        create(comunidad);
    }    
    
    public void actualizar(final Comunidad comunidad) throws AccesoException {
        edit(comunidad);
    }
    
    public Comunidad encontrar(java.lang.Object idUsuario) {
        return find(idUsuario);
    }
   
    public ArrayList<Comunidad> encontrarComunidades(java.lang.Object idUsuario) {
        return findAll(idUsuario);
    }
    
    public ArrayList<Comunidad> encontrarComunidadesNoRelacionadas(java.lang.Object idUsuario) {
        return findAllNotIn(idUsuario);
    }

    public ArrayList<Mensaje> encontrarMensajes(java.lang.Object idComunidad) {
        // return mensajeFindBy(idComunidad);
        return mensajeFindAll();
    }
    
    public void registrarMensaje (Mensaje mensaje) throws AccesoException {
        createMensaje(mensaje);
    }    
    
    public void actualizarMensaje (Mensaje mensaje) throws AccesoException {
        editMensaje(mensaje);
    }  
    
    public void eliminarMensaje (Mensaje mensaje) throws AccesoException {
        removeMensaje(mensaje);
    } 
    
    // Web Services

    private void create(Comunidad comunidad) {
        ServicioComunidad port = wsComunidad.getServicioComunidadPort();
        port.create(comunidad);
    }    
    
    private void edit(Comunidad comunidad) {
        ServicioComunidad port = wsComunidad.getServicioComunidadPort();
        port.edit(comunidad);
    }
    
    private Comunidad find(java.lang.Object id) {
        ServicioComunidad port = wsComunidad.getServicioComunidadPort();
        return port.find(id);
    }
   
    private ArrayList<Comunidad> findAll(java.lang.Object id) {
        ServicioComunidad port = wsComunidad.getServicioComunidadPort();
        return (ArrayList<Comunidad>) port.findAll(id);
    }
    
    private ArrayList<Comunidad> findAllNotIn(java.lang.Object id) {
        ServicioComunidad port = wsComunidad.getServicioComunidadPort();
        return (ArrayList<Comunidad>) port.findAllNotIn(id);
    }
   
    private ArrayList<Mensaje> mensajeFindBy(java.lang.Object idComunidad) {
        ServicioMensaje port = wsMensaje.getServicioMensajePort();
        return (ArrayList<Mensaje>) port.findBy((Integer) idComunidad);        
    }
    
    private ArrayList<Mensaje> mensajeFindAll() {
        ServicioMensaje port = wsMensaje.getServicioMensajePort();
        return (ArrayList<Mensaje>) port.findAll();
    }    

    private void createMensaje(Mensaje mensaje) {
        ServicioMensaje port = wsMensaje.getServicioMensajePort();
        port.create(mensaje);
    }    
    
    private void editMensaje(Mensaje mensaje) {
        ServicioMensaje port = wsMensaje.getServicioMensajePort();
        port.edit(mensaje);
    }   
    
    private void removeMensaje(Mensaje mensaje) {
        ServicioMensaje port = wsMensaje.getServicioMensajePort();
        port.remove(mensaje);
    } 
}
    

