package tfc.jvilarodr.logic;

import java.util.ArrayList;
import java.util.Map;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.xml.ws.WebServiceRef;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.comunidades.ServicioPerfil.Comunidades;
import tfc.jvilarodr.ws.comunidades.ServicioPerfil.Perfil;
import tfc.jvilarodr.ws.comunidades.ServicioPerfil.ServicioPerfil;
import tfc.jvilarodr.ws.usuarios.ServicioRecurso.Recurso;
import tfc.jvilarodr.ws.usuarios.ServicioRecurso.ServicioRecurso;
import tfc.jvilarodr.ws.usuarios.ServicioRelacion.Relacion;
import tfc.jvilarodr.ws.usuarios.ServicioRelacion.ServicioRelacion;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.ServicioUsuario;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.Usuario;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.Usuarios;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean
@SessionScoped
public class AccesoUsuario {
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/usuarios/ServicioUsuario.wsdl")
    private Usuarios wsUsuario;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/usuarios/ServicioRecurso.wsdl")
    private tfc.jvilarodr.ws.usuarios.ServicioRecurso.Usuarios wsRecurso;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/comunidades/ServicioPerfil.wsdl")
    private Comunidades wsPerfil;
    @WebServiceRef(wsdlLocation = "WEB-INF/wsdl/localhost_8080/tfc-ejb/usuarios/ServicioRelacion.wsdl")
    private tfc.jvilarodr.ws.usuarios.ServicioRelacion.Usuarios wsRelacion;

    public static AccesoUsuario getCurrentInstance() {
        AccesoUsuario result = null;
        FacesContext context = FacesContext.getCurrentInstance();
        Map<String, Object> appMap = FacesContext.getCurrentInstance().
                getExternalContext().getApplicationMap();
        result = (AccesoUsuario) appMap.get("accesoUsuario");
        
        Map<String, Object> sessionMap = context.getExternalContext().getSessionMap();
        if (null == (result = (AccesoUsuario) sessionMap.get("accesoUsuario"))){
            result = context.getApplication().evaluateExpressionGet(context, "#{accesoUsuario}",
                    AccesoUsuario.class);
        }
        
        assert(null != result);

        return result;
    }   
    
    public void registrar(final Usuario usuario) throws AccesoException {
        create(usuario);
    }    
    
    public void actualizar(final Usuario usuario) throws AccesoException {
        edit(usuario);
    }
    
    public Usuario encontrar(java.lang.Object id) {
        return find(id);
    }
    
    public Usuario encontrarPorEmail(String email) {        
        return findBy(email);
    }
            
    public ArrayList<Usuario> encontrarUsuarios(java.lang.Object idUsuario) {
        return findAll(idUsuario);
    }
    
    public ArrayList<Usuario> encontrarUsuariosNoRelacionados(java.lang.Object idUsuario) {
        return findAllNotIn(idUsuario);
    }

    public ArrayList<Recurso> encontrarRecursos(java.lang.Object idUsuario) {
        return recursoFindBy(idUsuario);
    }
    
    public void registrarRecurso (Recurso recurso) throws AccesoException {
        createRecurso(recurso);
    }    
    
    public void actualizarRecurso (Recurso recurso) throws AccesoException {
        editRecurso(recurso);
    }  
    
    public void eliminarRecurso (Recurso recurso) throws AccesoException {
        removeRecurso(recurso);
    } 
    
    public ArrayList<Perfil> encontrarPerfiles(java.lang.Object idUsuario) {
        return perfilFindBy(idUsuario);
    }
    
    public void registrarPerfil (Perfil perfil) throws AccesoException {
        createPerfil(perfil);
    }    
    
    public void actualizarPerfil (Perfil perfil) throws AccesoException {
        editPerfil(perfil);
    }  
    
    public void eliminarPerfil (Perfil perfil) throws AccesoException {
        removePerfil(perfil);
    } 

    public ArrayList<Relacion> encontrarRelaciones(java.lang.Object idUsuario) {
        return relacionFindBy(idUsuario);
    }
    
    public void registrarRelacion (Relacion relacion) throws AccesoException {
        createRelacion(relacion);
    }    
    
    public void actualizarRelacion (Relacion relacion) throws AccesoException {
        editRelacion(relacion);
    }  
    
    public void eliminarRelacion (Relacion relacion) throws AccesoException {
        removeRelacion(relacion);
    }   
    
    // Web Services

    private void create(Usuario usuario) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        port.create(usuario);
    }    
    
    private void edit(Usuario usuario) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        port.edit(usuario);
    }
    
    private Usuario find(java.lang.Object id) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        return port.find(id);
    }
    
    private Usuario findBy(String email) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        return port.findBy(email);
    }

    private ArrayList<Usuario> findAll(java.lang.Object id) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        return (ArrayList<Usuario>) port.findAll(id);
    }
    
    private ArrayList<Usuario> findAllNotIn(java.lang.Object id) {
        ServicioUsuario port = wsUsuario.getServicioUsuarioPort();
        return (ArrayList<Usuario>) port.findAllNotIn(id);
    }    
    
    private ArrayList<Recurso> recursoFindBy(java.lang.Object idUsuario) {
        ServicioRecurso port = wsRecurso.getServicioRecursoPort();
        return (ArrayList<Recurso>) port.findBy((Integer) idUsuario);        
    }

    private void createRecurso(Recurso recurso) {
        ServicioRecurso port = wsRecurso.getServicioRecursoPort();
        port.create(recurso);
    }    
    
    private void editRecurso(Recurso recurso) {
        ServicioRecurso port = wsRecurso.getServicioRecursoPort();
        port.edit(recurso);
    }   
    
    private void removeRecurso(Recurso recurso) {
        ServicioRecurso port = wsRecurso.getServicioRecursoPort();
        port.remove(recurso);
    } 
    
    private ArrayList<Perfil> perfilFindBy(java.lang.Object idUsuario) {
        ServicioPerfil port = wsPerfil.getServicioPerfilPort();
        return (ArrayList<Perfil>) port.findBy((Integer) idUsuario);        
    }

    private void createPerfil(Perfil perfil) {
        ServicioPerfil port = wsPerfil.getServicioPerfilPort();
        port.create(perfil);
    }    
    
    private void editPerfil(Perfil perfil) {
        ServicioPerfil port = wsPerfil.getServicioPerfilPort();
        port.edit(perfil);
    }   
    
    private void removePerfil(Perfil perfil) {
        ServicioPerfil port = wsPerfil.getServicioPerfilPort();
        port.remove(perfil);
    } 
    
    private ArrayList<Relacion> relacionFindBy(java.lang.Object idUsuario) {
        ServicioRelacion port = wsRelacion.getServicioRelacionPort();
        return (ArrayList<Relacion>) port.findBy((Integer) idUsuario);        
    }

    private void createRelacion(Relacion relacion) {
        ServicioRelacion port = wsRelacion.getServicioRelacionPort();
        port.create(relacion);
    }    
    
    private void editRelacion(Relacion relacion) {
        ServicioRelacion port = wsRelacion.getServicioRelacionPort();
        port.edit(relacion);
    }   
    
    private void removeRelacion(Relacion relacion) {
        ServicioRelacion port = wsRelacion.getServicioRelacionPort();
        port.remove(relacion);
    }     
}
