package tfc.jvilarodr.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import tfc.jvilarodr.logic.AccesoComunidad;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.comunidades.ServicioComunidad.Comunidad;
import tfc.jvilarodr.ws.usuarios.ServicioCredenciales.Credenciales;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean(name="comunidades")
@RequestScoped
public class ServicioComunidades extends AbstractServicio<Credenciales> implements Serializable {
    
    private static final long serialVersionUID = 1L;
    
    private static final ArrayList<ServicioComunidades.Item> listaComunidades = new ArrayList<ServicioComunidades.Item>();    
    private Comunidad nuevoComunidad = new Comunidad();    
    private boolean insertando = false;
    
    public void encontrarComunidades() {
        System.out.println("[DEBUG]: ServicioComunidades.encontrarComunidades IdUsuario "+getCurrentUser().getIdUsuario());

        if (listaComunidades.isEmpty()) {
            for(Comunidad comunidad : AccesoComunidad.getCurrentInstance().encontrarComunidades(getCurrentUser().getIdUsuario())) {
                ServicioComunidades.Item item = new ServicioComunidades.Item(comunidad);
                listaComunidades.add(item);
            }
        }
        
        for (ServicioComunidades.Item item : listaComunidades) {
            System.out.println("[DEBUG]: ServicioComunidades.encontrarComunidades listaComunidades "+item.getComunidad().getIdComunidad()+", "+item.getComunidad().getNombre());
        }
    }
   
    public ArrayList<ServicioComunidades.Item> getListaComunidades() {
        return listaComunidades;
    }
    
    public String editar(ServicioComunidades.Item item) {
        item.setEditable(true);
        item.setActualizable(true);
        item.setEliminable(true);
        return null;        
    }
    
    public String actualizar(ServicioComunidades.Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);

        try {
            AccesoComunidad.getCurrentInstance().actualizar(item.getComunidad());
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;
    }
         
    public String registrar() {
        setInsertando(false);

        try {
            AccesoComunidad.getCurrentInstance().registrar(nuevoComunidad);
            listaComunidades.clear();
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }

        return null;        
    } 
    
    public void activarInsertando() {
        insertando = true;
    }
    
    public boolean isInsertando() {
        return insertando;
    }
    
    public void setInsertando(boolean insertando) {
        this.insertando = insertando;
    }
    
    public Comunidad getNuevoComunidad() {
        return nuevoComunidad;
    }
    
    public void setNuevoComunidad(Comunidad comunidad) {
        nuevoComunidad = comunidad;
    }
    
    public static class Item {
		
        Comunidad comunidad;
        boolean editable;
        boolean actualizable;
        boolean eliminable;        
        
        public Item(Comunidad comunidad) {
                this.comunidad = comunidad;
                this.editable = false;
                this.actualizable = false;
                this.eliminable = false;
        }

        public Comunidad getComunidad() {
            return comunidad;
        }

        public void setComunidad(Comunidad comunidad) {
            this.comunidad = comunidad;
        }

        public boolean isEditable() {
                return editable;
        }

        public void setEditable(boolean editable) {
                this.editable = editable;
        }
        
        public boolean isActualizable() {
                return actualizable;
        }

        public void setActualizable(boolean actualizable) {
                this.actualizable = actualizable;
        }
        
        public boolean isEliminable() {
                return eliminable;
        }

        public void setEliminable(boolean eliminable) {
                this.eliminable = eliminable;
        }
    }         
}
