package tfc.jvilarodr.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.faces.model.SelectItem;
import tfc.jvilarodr.logic.AccesoComunidad;
import tfc.jvilarodr.logic.AccesoUsuario;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.comunidades.ServicioComunidad.Comunidad;
import tfc.jvilarodr.ws.comunidades.ServicioPerfil.Perfil;
import tfc.jvilarodr.ws.usuarios.ServicioCredenciales.Credenciales;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean(name="perfiles")
@RequestScoped
public class ServicioPerfiles extends AbstractServicio<Credenciales> implements Serializable {
    
    private static final long serialVersionUID = 1L;
    
    private static final ArrayList<Item> listaPerfiles = new ArrayList<Item>();
    private static final ArrayList<SelectItem> listaComunidades = new ArrayList<SelectItem>();
    private static final ArrayList<SelectItem> listaComunidadesNoRelacionadas = new ArrayList<SelectItem>();
    
    private Perfil nuevoPerfil = new Perfil();
    
    private boolean insertando = false;
    
    public void encontrarPerfiles() {
        if (listaPerfiles.isEmpty()) {
            for(Perfil perfil : AccesoUsuario.getCurrentInstance().encontrarPerfiles(getCurrentUser().getIdUsuario())) {
                Item item = new Item(perfil);
                listaPerfiles.add(item);
            }
        }
    }
   
    public ArrayList<Item> getListaPerfiles() {
        return listaPerfiles;
    }
    
    public String editar(Item item) {
        item.setEditable(true);
        item.setActualizable(true);
        item.setEliminable(true);
        return null;        
    }
    
    public String actualizar(Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);

        try {
            AccesoUsuario.getCurrentInstance().actualizarPerfil(item.getPerfil());
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;
    }
    
    public String eliminar(Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);
        
        try {
            AccesoUsuario.getCurrentInstance().eliminarPerfil(item.getPerfil());
            listaPerfiles.clear();
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;        
    }  
    
    public String registrar() {
        setInsertando(false);

        int idUsuario = getCurrentUser().getIdUsuario();
        if(idUsuario != 0) {
            try {
                nuevoPerfil.setIdUsuario(idUsuario);
                AccesoUsuario.getCurrentInstance().registrarPerfil(nuevoPerfil);
                listaPerfiles.clear();
            } catch (AccesoException ex) {
                Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return null;        
    } 

    public void setListaComunidades() { 
        if (listaComunidades.isEmpty()) {
            for (Comunidad comunidad : AccesoComunidad.getCurrentInstance().encontrarComunidades(getCurrentUser().getIdUsuario())) {
                listaComunidades.add(new SelectItem(comunidad.getIdComunidad(),comunidad.getNombre()));
            }
        }
    }     
    
    public ArrayList<SelectItem> getListaComunidades() {
        return listaComunidades;
    }

    public void setListaComunidadesNoRelacionadas() { 
        if (listaComunidadesNoRelacionadas.isEmpty()) {
            for (Comunidad comunidad : AccesoComunidad.getCurrentInstance().encontrarComunidades(getCurrentUser().getIdUsuario())) {
                listaComunidadesNoRelacionadas.add(new SelectItem(comunidad.getIdComunidad(),comunidad.getNombre()));
            }
        }
    }     
    
    public ArrayList<SelectItem> getListaComunidadesNoRelacionadas() {
        return listaComunidadesNoRelacionadas;
    }
    
    public String getNombreComunidad(Item item) {
        java.lang.Object id = item.getPerfil().getIdComunidad();
        if ((Integer) id!=0) {
            Comunidad comunidad = AccesoComunidad.getCurrentInstance().encontrar(id);
            return comunidad.getNombre();
        } else {
            return "-seleccione comunidad-";            
        }

    }    
    
    public void activarInsertando() {
        insertando = true;
    }
    
    public boolean isInsertando() {
        return insertando;
    }
    
    public void setInsertando(boolean insertando) {
        this.insertando = insertando;
    }
    
    public Perfil getNuevoPerfil() {
        return nuevoPerfil;
    }
    
    public void setNuevoPerfil(Perfil perfil) {
        nuevoPerfil = perfil;
    }
    
    public static class Item {
		
        Perfil perfil;
        boolean editable;
        boolean actualizable;
        boolean eliminable;        
        
        public Item(Perfil perfil) {
                this.perfil = perfil;
                this.editable = false;
                this.actualizable = false;
                this.eliminable = false;
        }

        public Perfil getPerfil() {
            return perfil;
        }

        public void setPerfil(Perfil perfil) {
            this.perfil = perfil;
        }

        public boolean isEditable() {
                return editable;
        }

        public void setEditable(boolean editable) {
                this.editable = editable;
        }
        
        public boolean isActualizable() {
                return actualizable;
        }

        public void setActualizable(boolean actualizable) {
                this.actualizable = actualizable;
        }
        
        public boolean isEliminable() {
                return eliminable;
        }

        public void setEliminable(boolean eliminable) {
                this.eliminable = eliminable;
        }
    }         
}
