package tfc.jvilarodr.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import tfc.jvilarodr.logic.AccesoUsuario;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.usuarios.ServicioCredenciales.Credenciales;
import tfc.jvilarodr.ws.usuarios.ServicioRecurso.Recurso;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean(name="recursos")
@RequestScoped
public class ServicioRecursos extends AbstractServicio<Credenciales> implements Serializable {
    
    private static final long serialVersionUID = 1L;  
    
    private static final ArrayList<ServicioRecursos.Item> listaRecursos = new ArrayList<ServicioRecursos.Item>();    
    private Recurso nuevoRecurso = new Recurso();    
    private boolean insertando = false;
    
    public void encontrarRecursos() {
        if (listaRecursos.isEmpty()) {
            for(Recurso recurso : AccesoUsuario.getCurrentInstance().encontrarRecursos(getCurrentUser().getIdUsuario())) {
                ServicioRecursos.Item item = new ServicioRecursos.Item(recurso);
                listaRecursos.add(item);
            }
        }
    }
   
    public ArrayList<ServicioRecursos.Item> getListaRecursos() {
        return listaRecursos;
    }
    
    public String editar(ServicioRecursos.Item item) {
        item.setEditable(true);
        item.setActualizable(true);
        item.setEliminable(true);
        return null;        
    }
    
    public String actualizar(ServicioRecursos.Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);

        try {
            AccesoUsuario.getCurrentInstance().actualizarRecurso(item.getRecurso());
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;
    }
    
    public String eliminar(ServicioRecursos.Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);
        
        try {
            AccesoUsuario.getCurrentInstance().eliminarRecurso(item.getRecurso());
            listaRecursos.clear();
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;        
    }  
    
    public String registrar() {
        setInsertando(false);

        int idUsuario = getCurrentUser().getIdUsuario();
        if(idUsuario != 0) {
            try {
                nuevoRecurso.setIdUsuario(idUsuario);
                AccesoUsuario.getCurrentInstance().registrarRecurso(nuevoRecurso);
                listaRecursos.clear();
            } catch (AccesoException ex) {
                Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return null;        
    } 
    
    public void activarInsertando() {
        insertando = true;
    }
    
    public boolean isInsertando() {
        return insertando;
    }
    
    public void setInsertando(boolean insertando) {
        this.insertando = insertando;
    }
    
    public Recurso getNuevoRecurso() {
        return nuevoRecurso;
    }
    
    public void setNuevoRecurso(Recurso recurso) {
        nuevoRecurso = recurso;
    }
    
    public static class Item {
		
        Recurso recurso;
        boolean editable;
        boolean actualizable;
        boolean eliminable;        
        
        public Item(Recurso recurso) {
                this.recurso = recurso;
                this.editable = false;
                this.actualizable = false;
                this.eliminable = false;
        }

        public Recurso getRecurso() {
            return recurso;
        }

        public void setRecurso(Recurso recurso) {
            this.recurso = recurso;
        }

        public boolean isEditable() {
                return editable;
        }

        public void setEditable(boolean editable) {
                this.editable = editable;
        }
        
        public boolean isActualizable() {
                return actualizable;
        }

        public void setActualizable(boolean actualizable) {
                this.actualizable = actualizable;
        }
        
        public boolean isEliminable() {
                return eliminable;
        }

        public void setEliminable(boolean eliminable) {
                this.eliminable = eliminable;
        }
    }         
}