package tfc.jvilarodr.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.faces.model.SelectItem;
import tfc.jvilarodr.logic.AccesoUsuario;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.usuarios.ServicioCredenciales.Credenciales;
import tfc.jvilarodr.ws.usuarios.ServicioRelacion.Relacion;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.Usuario;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean(name="relaciones")
@RequestScoped
public class ServicioRelaciones extends AbstractServicio<Credenciales> implements Serializable {
    
    private static final long serialVersionUID = 1L;
    
    private static final ArrayList<Item> listaRelaciones = new ArrayList<Item>();
    private static final ArrayList<SelectItem> listaEstadoInvitacion = new ArrayList<SelectItem>();
    private static final ArrayList<SelectItem> listaUsuarios = new ArrayList<SelectItem>();
    private static final ArrayList<SelectItem> listaUsuariosNoRelacionados = new ArrayList<SelectItem>();
    
    private Relacion nuevoRelacion = new Relacion();
    
    private boolean insertando = false;
    
    public ServicioRelaciones() {
        if (listaEstadoInvitacion.isEmpty()) {
            setListaEstadoInvitacion();
        }
    }
    
    public void encontrarRelaciones() {
        if (listaRelaciones.isEmpty()) {
            for(Relacion relacion : AccesoUsuario.getCurrentInstance().encontrarRelaciones(getCurrentUser().getIdUsuario())) {
                ServicioRelaciones.Item item = new ServicioRelaciones.Item(relacion);
                listaRelaciones.add(item);
            }
        }
    }
       
    public ArrayList<Item> getListaRelaciones() {
        return listaRelaciones;
    }
    
    public String editar(Item item) {
        item.setEditable(true);
        item.setActualizable(true);
        item.setEliminable(true);
        return null;        
    }
    
    public String actualizar(Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);

        try {
            AccesoUsuario.getCurrentInstance().actualizarRelacion(item.getRelacion());
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;
    }
    
    public String eliminar(Item item) {
	item.setEditable(false);
        item.setActualizable(false);
        item.setEliminable(false);
        
        try {
            AccesoUsuario.getCurrentInstance().eliminarRelacion(item.getRelacion());
            listaRelaciones.clear();
        } catch (AccesoException ex) {
            Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
        }        
        return null;        
    }  
    
    public String registrar() {
        setInsertando(false);

        int idUsuario = getCurrentUser().getIdUsuario();
        if(idUsuario != 0) {
            try {
                nuevoRelacion.setIdUsuario1(idUsuario);
                AccesoUsuario.getCurrentInstance().registrarRelacion(nuevoRelacion);
                listaRelaciones.clear();
            } catch (AccesoException ex) {
                Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return null;        
    } 
    
    private void setListaEstadoInvitacion() {               
        listaEstadoInvitacion.add(new SelectItem("0","Pendiente"));
        listaEstadoInvitacion.add(new SelectItem("1","Aceptada"));
        listaEstadoInvitacion.add(new SelectItem("2","Rechazada"));
        listaEstadoInvitacion.add(new SelectItem("3","Anulada"));
    }    
    
    public ArrayList<SelectItem> getListaEstadoInvitacion() {       
        return listaEstadoInvitacion;
    }
    
    public String getEstadoInvitacion(Item item) {
        String estadoInvitacion = "Desconocido";
        switch (item.getRelacion().getInvitacion()) {
            case 0: { estadoInvitacion = "Pendiente"; break; }
            case 1: { estadoInvitacion = "Aceptada"; break; }
            case 2: { estadoInvitacion = "Rechazada"; break; }
            case 3: { estadoInvitacion = "Anulada"; }                    
        }    
        return estadoInvitacion;
    } 
 
    public void setListaUsuarios() { 
        if (listaUsuarios.isEmpty()) {
            for (Usuario usuario : AccesoUsuario.getCurrentInstance().encontrarUsuarios(getCurrentUser().getIdUsuario())) {
                listaUsuarios.add(new SelectItem(usuario.getIdUsuario(),usuario.getApellido()+" "+usuario.getNombre()));
            }
        }
    }     
    
    public ArrayList<SelectItem> getListaUsuarios() {
        return listaUsuarios;
    }
    
    public void setListaUsuariosNoRelacionados() { 
        if (listaUsuariosNoRelacionados.isEmpty()) {
            for (Usuario usuario : AccesoUsuario.getCurrentInstance().encontrarUsuariosNoRelacionados(getCurrentUser().getIdUsuario())) {
                listaUsuariosNoRelacionados.add(new SelectItem(usuario.getIdUsuario(),usuario.getApellido()+" "+usuario.getNombre()));
            }
        }
    }     
    
    public ArrayList<SelectItem> getListaUsuariosNoRelacionados() {
        return listaUsuariosNoRelacionados;
    }
    
    public String getApellidosNombre(Item item) {
        java.lang.Object id = item.getRelacion().getIdUsuario2();
        if ((Integer) id!= 0) {
            Usuario usuario = AccesoUsuario.getCurrentInstance().encontrar(id);
            return usuario.getApellido()+" "+usuario.getNombre();
        } else {
            return "-seleccione usuario-";
        }
    }
    
    public void activarInsertando() {
        insertando = true;
    }
    
    public boolean isInsertando() {
        return insertando;
    }
    
    public void setInsertando(boolean insertando) {
        this.insertando = insertando;
    }
    
    public Relacion getNuevoRelacion() {
        return nuevoRelacion;
    }
    
    public void setNuevoRelacion(Relacion relacion) {
        nuevoRelacion = relacion;
    }
    
    public static class Item {
		
        Relacion relacion;
        boolean editable;
        boolean actualizable;
        boolean eliminable;        
        
        public Item(Relacion relacion) {
                this.relacion = relacion;
                this.editable = false;
                this.actualizable = false;
                this.eliminable = false;
        }

        public Relacion getRelacion() {
            return relacion;
        }

        public void setRelacion(Relacion relacion) {
            this.relacion = relacion;
        }

        public boolean isEditable() {
                return editable;
        }

        public void setEditable(boolean editable) {
                this.editable = editable;
        }
        
        public boolean isActualizable() {
                return actualizable;
        }

        public void setActualizable(boolean actualizable) {
                this.actualizable = actualizable;
        }
        
        public boolean isEliminable() {
                return eliminable;
        }

        public void setEliminable(boolean eliminable) {
                this.eliminable = eliminable;
        }
    }         
}
