package tfc.jvilarodr.view;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.application.FacesMessage;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.validator.ValidatorException;
import tfc.jvilarodr.logic.AccesoCredenciales;
import tfc.jvilarodr.logic.AccesoUsuario;
import tfc.jvilarodr.logic.exceptions.AccesoException;
import tfc.jvilarodr.ws.usuarios.ServicioCredenciales.Credenciales;
import tfc.jvilarodr.ws.usuarios.ServicioUsuario.Usuario;

/**
 * @author jvilarodr@uoc.edu
 * @version tfc
 * @since 18/06/2012
 */
@ManagedBean(name="usuarios")
@RequestScoped
public class ServicioUsuarios extends AbstractServicio<Credenciales> {
    
    private static final long serialVersionUID = 1L;
        
    private Usuario usuarioActual;
    private AccesoUsuario acceso;
    private Object email;
    
    public ServicioUsuarios() {
    }

    public void validaEmail(FacesContext context, UIComponent component, Object value) throws ValidatorException {
        String emailStr = (String) value;
        if (-1 == emailStr.indexOf("@") || -1 == emailStr.indexOf(".")) {
            throw new ValidatorException(new FacesMessage("Correo electrónico no válido."));
        } else {
            Usuario usuario = AccesoUsuario.getCurrentInstance().encontrarPorEmail(emailStr);
            if(null != usuario && usuario.getIdUsuario() != getCurrentUser().getIdUsuario()) {
                throw new ValidatorException(new FacesMessage("Correo electrónico ya utilizado."));
            }
        }
    }
    
    public void leerUsuarioActual() {
        int idUsuario = getCurrentUser().getIdUsuario();
        if (idUsuario != 0) {                   
            usuarioActual = AccesoUsuario.getCurrentInstance().encontrar(idUsuario);
        } else {
            usuarioActual = new Usuario();
        } 
    }
           
    public String actualizar() {
        String result = null;

        int idUsuario = getCurrentUser().getIdUsuario();
        if (idUsuario != 0) { 
            try {
                usuarioActual.setIdUsuario(idUsuario);
                AccesoUsuario.getCurrentInstance().actualizar(usuarioActual);
                result = "/index?faces-redirect=true";
            } catch (AccesoException ex) {
                Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
            }
        } else {
            try {
                AccesoUsuario.getCurrentInstance().registrar(usuarioActual);
                Usuario usuario = AccesoUsuario.getCurrentInstance().encontrarPorEmail(usuarioActual.getEmail());                         
                Credenciales credencialesAutenticadas = AccesoCredenciales.getCurrentInstance().encontrar((Integer) getCurrentUser().getIdCredenciales());
                credencialesAutenticadas.setIdUsuario(usuario.getIdUsuario());  
                AccesoCredenciales.getCurrentInstance().actualizar(credencialesAutenticadas);
                setCurrentUser(credencialesAutenticadas);

                result = "/index?faces-redirect=true";
            } catch (AccesoException ex) {
                Logger.getLogger(ServicioUsuarios.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return result;
    }

    public void setUsuarioActual(Usuario usuario) {
        this.usuarioActual = usuario;
    }
    
    public Usuario getUsuarioActual() {
        if(null == usuarioActual) {
            usuarioActual = new Usuario();
        }
        return usuarioActual;
    }    
    
    public void setNombre(String nombre) {
        usuarioActual.setNombre(nombre);
    }
    
    public String getNombre() {
        return usuarioActual.getNombre();
    }
    
    public void setApellido(String apellido) {
        usuarioActual.setApellido(apellido);
    }
    
    public String getApellido() {
        return usuarioActual.getApellido();
    }
    
    public void setEmail(String email) {
        usuarioActual.setEmail(email);
    }
    
    public String getEmail() {
        return usuarioActual.getEmail();
    } 
        
}
